@@ -18,8 +18,8 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 #ifndef _GST_VIDEO_ENCODER_H_
@@ -39,7 +39,7 @@ G_BEGIN_DECLS
   (G_TYPE_INSTANCE_GET_CLASS((obj),GST_TYPE_VIDEO_ENCODER,GstVideoEncoderClass))
 #define GST_IS_VIDEO_ENCODER(obj) \
   (G_TYPE_CHECK_INSTANCE_TYPE((obj),GST_TYPE_VIDEO_ENCODER))
-#define GST_IS_VIDEO_ENCODER_CLASS(klass) \
+#define GST_IS_VIDEO_ENCODER_CLASS(obj) \
   (G_TYPE_CHECK_CLASS_TYPE((klass),GST_TYPE_VIDEO_ENCODER))
 #define GST_VIDEO_ENCODER_CAST(enc) ((GstVideoEncoder*)enc)
 
@@ -83,13 +83,8 @@ G_BEGIN_DECLS
  * GST_VIDEO_ENCODER_FLOW_DROPPED:
  *
  * Returned when the event/buffer should be dropped.
- *
- * Deprecated: since 1.8. use gst_video_encoder_finish_frame with
- * a %NULL frame->output_buffer to drop the frame instead.
  */
-#ifndef GST_DISABLE_DEPRECATED
 #define GST_VIDEO_ENCODER_FLOW_DROPPED GST_FLOW_CUSTOM_SUCCESS_1
-#endif
 
 /**
  * GST_VIDEO_ENCODER_INPUT_SEGMENT:
@@ -153,7 +148,7 @@ struct _GstVideoEncoder
   /*< private >*/
   GstVideoEncoderPrivate *priv;
 
-  gpointer padding[GST_PADDING_LARGE];
+  void         *padding[GST_PADDING_LARGE];
 };
 
 /**
@@ -177,11 +172,10 @@ struct _GstVideoEncoder
  * @handle_frame:   Provides input frame to subclass.
  * @reset:          Optional.
  *                  Allows subclass (encoder) to perform post-seek semantics reset.
- *                  Deprecated.
  * @finish:         Optional.
  *                  Called to request subclass to dispatch any pending remaining
  *                  data (e.g. at EOS).
- * @pre_push:       Optional.
+ * @pre_push:   Optional.
  *                  Allows subclass to push frame downstream in whatever
  *                  shape or form it deems appropriate.  If not provided,
  *                  provided encoded frame data is simply pushed downstream.
@@ -216,24 +210,6 @@ struct _GstVideoEncoder
  *                      Propose buffer allocation parameters for upstream elements.
  *                      Subclasses should chain up to the parent implementation to
  *                      invoke the default handler.
- * @flush:              Optional.
- *                      Flush all remaining data from the encoder without
- *                      pushing it downstream. Since: 1.2
- * @sink_query:     Optional.
- *                  Query handler on the sink pad. This function should
- *                  return TRUE if the query could be performed. Subclasses
- *                  should chain up to the parent implementation to invoke the
- *                  default handler. Since: 1.4
- * @src_query:      Optional.
- *                  Query handler on the source pad. This function should
- *                  return TRUE if the query could be performed. Subclasses
- *                  should chain up to the parent implementation to invoke the
- *                  default handler. Since: 1.4
- * @transform_meta: Optional. Transform the metadata on the input buffer to the
- *                  output buffer. By default this method is copies all meta without
- *                  tags and meta with only the "video" tag. subclasses can
- *                  implement this method and return %TRUE if the metadata is to be
- *                  copied. Since: 1.6
  *
  * Subclasses can override any of the available virtual methods or not, as
  * needed. At minimum @handle_frame needs to be overridden, and @set_format
@@ -283,118 +259,61 @@ struct _GstVideoEncoderClass
 
   gboolean      (*propose_allocation) (GstVideoEncoder * encoder,
                                        GstQuery * query);
-  gboolean      (*flush)              (GstVideoEncoder *encoder);
-
-  gboolean      (*sink_query)     (GstVideoEncoder *encoder,
-				   GstQuery *query);
-
-  gboolean      (*src_query)      (GstVideoEncoder *encoder,
-				   GstQuery *query);
-
-  gboolean      (*transform_meta) (GstVideoEncoder *encoder,
-                                   GstVideoCodecFrame *frame,
-                                   GstMeta * meta);
 
   /*< private >*/
-  gpointer       _gst_reserved[GST_PADDING_LARGE-4];
+  gpointer       _gst_reserved[GST_PADDING_LARGE];
 };
 
-GST_VIDEO_API
 GType                gst_video_encoder_get_type (void);
 
-GST_VIDEO_API
-GstVideoCodecState*  gst_video_encoder_get_output_state (GstVideoEncoder *encoder) G_GNUC_WARN_UNUSED_RESULT;
+GstVideoCodecState*  gst_video_encoder_get_output_state (GstVideoEncoder *encoder);
 
-GST_VIDEO_API
 GstVideoCodecState*  gst_video_encoder_set_output_state (GstVideoEncoder * encoder,
 							 GstCaps * caps,
-							 GstVideoCodecState * reference) G_GNUC_WARN_UNUSED_RESULT;
+							 GstVideoCodecState * reference);
 
-GST_VIDEO_API
 gboolean             gst_video_encoder_negotiate        (GstVideoEncoder * encoder);
 
-GST_VIDEO_API
 GstVideoCodecFrame*  gst_video_encoder_get_frame        (GstVideoEncoder *encoder,
-						         int frame_number) G_GNUC_WARN_UNUSED_RESULT;
+						         int frame_number);
+GstVideoCodecFrame*  gst_video_encoder_get_oldest_frame (GstVideoEncoder *encoder);
 
-GST_VIDEO_API
-GstVideoCodecFrame*  gst_video_encoder_get_oldest_frame (GstVideoEncoder *encoder) G_GNUC_WARN_UNUSED_RESULT;
+GList *              gst_video_encoder_get_frames       (GstVideoEncoder *encoder);
 
-GST_VIDEO_API
-GList *              gst_video_encoder_get_frames       (GstVideoEncoder *encoder) G_GNUC_WARN_UNUSED_RESULT;
-
-GST_VIDEO_API
 GstBuffer *          gst_video_encoder_allocate_output_buffer (GstVideoEncoder * encoder,
-                                                               gsize size) G_GNUC_WARN_UNUSED_RESULT;
+                                                               gsize size);
 
-GST_VIDEO_API
 GstFlowReturn        gst_video_encoder_allocate_output_frame  (GstVideoEncoder *encoder,
 						               GstVideoCodecFrame *frame,
                                                                gsize size);
 
-GST_VIDEO_API
 GstFlowReturn        gst_video_encoder_finish_frame (GstVideoEncoder *encoder,
 						     GstVideoCodecFrame *frame);
 
-GST_VIDEO_API
-GstFlowReturn        gst_video_encoder_finish_subframe (GstVideoEncoder * encoder,
-						     GstVideoCodecFrame * frame);
-
-GST_VIDEO_API
 GstCaps *            gst_video_encoder_proxy_getcaps (GstVideoEncoder * enc,
 						      GstCaps         * caps,
-                                                      GstCaps         * filter) G_GNUC_WARN_UNUSED_RESULT;
+                                                      GstCaps         * filter);
+void                 gst_video_encoder_set_discont (GstVideoEncoder *encoder);
+gboolean             gst_video_encoder_get_discont (GstVideoEncoder *encoder);
 
-GST_VIDEO_API
 void                 gst_video_encoder_set_latency (GstVideoEncoder *encoder,
 						    GstClockTime min_latency,
 						    GstClockTime max_latency);
-
-GST_VIDEO_API
 void		     gst_video_encoder_get_latency (GstVideoEncoder *encoder,
 						    GstClockTime *min_latency,
 						    GstClockTime *max_latency);
 
-GST_VIDEO_API
 void                 gst_video_encoder_set_headers (GstVideoEncoder *encoder,
 						    GList *headers);
 
-GST_VIDEO_API
 void                 gst_video_encoder_merge_tags  (GstVideoEncoder *encoder,
                                                     const GstTagList *tags,
                                                     GstTagMergeMode mode);
 
-GST_VIDEO_API
 void                 gst_video_encoder_get_allocator (GstVideoEncoder *encoder,
                                                       GstAllocator **allocator,
                                                       GstAllocationParams *params);
 
-GST_VIDEO_API
-void                 gst_video_encoder_set_min_pts(GstVideoEncoder *encoder, GstClockTime min_pts);
-
-GST_VIDEO_API
-void                 gst_video_encoder_set_qos_enabled (GstVideoEncoder * encoder, gboolean enabled);
-
-GST_VIDEO_API
-gboolean             gst_video_encoder_is_qos_enabled (GstVideoEncoder * encoder);
-
-GST_VIDEO_API
-GstClockTimeDiff     gst_video_encoder_get_max_encode_time (GstVideoEncoder *encoder, GstVideoCodecFrame * frame);
-
-GST_VIDEO_API
-void                 gst_video_encoder_set_min_force_key_unit_interval (GstVideoEncoder * encoder,
-                                                                        GstClockTime      interval);
-GST_VIDEO_API
-GstClockTime         gst_video_encoder_get_min_force_key_unit_interval (GstVideoEncoder * encoder);
-
-GST_VIDEO_API
-void                 gst_video_encoder_release_frame (GstVideoEncoder *encoder, GstVideoCodecFrame *frame);
-
-GST_VIDEO_API
-void                 gst_video_encoder_drop_frame (GstVideoEncoder *encoder, GstVideoCodecFrame *frame);
-
-G_DEFINE_AUTOPTR_CLEANUP_FUNC(GstVideoEncoder, gst_object_unref)
-
 G_END_DECLS
 
 #endif
